@@ -25,7 +25,9 @@ def find_notebooks():
     notebook_info = []
 
     for nb in notebooks:
-        versions = get_available_versions(nb.replace(".py", ".yaml"))
+        versions = get_available_versions(
+            nb.replace(".py", ".yaml"), include_private=False
+        )
         notebook_name = os.path.basename(nb)[:-3]
         notebook_info.extend((nb, notebook_name, v) for v in versions)
 
@@ -53,9 +55,6 @@ def test_notebook(notebook_path, notebook_name, notebook_version, output_directo
 
     notebook_dir = os.path.dirname(notebook_path)
 
-    if notebook_name != "ceds":
-        return
-
     run_notebook_and_check_results(
         notebook_name,
         version=notebook_version,
@@ -86,6 +85,12 @@ def run_notebook_and_check_results(notebook, version, notebook_dir, output_direc
         )
         logger.info(f"Remote book exists. Expecting hash: {existing_book.hash()}")
 
+        if existing_book.edition != target_book.edition:
+            raise ValueError(
+                f"Edition of calculated book doesn't match the remote bookshelf "
+                f"({target_book.edition} != {existing_book.edition})"
+            )
+
         if existing_book.hash() != target_book.hash():
             raise ValueError(
                 f"Hash of calculated book doesn't match the remote bookshelf "
